import 'package:flutter/material.dart';

import 'package:tetrisdual/layout/board.dart';
import 'package:tetrisdual/provider/data.dart';
import 'package:tetrisdual/utils/game_utils.dart';

class Game {
  static Widget buildGameWidget(Data myProvider, double screenWidth) {
    return !myProvider.isGameFinished
        ? Board.buildGameBoard(myProvider, screenWidth)
        : Game.buildEndGameMessage(myProvider);
  }

  static TextButton buildQuitGameButton(Data myProvider) {
    return TextButton(
      child: const Image(
        image: AssetImage('assets/icons/button_back.png'),
        fit: BoxFit.fill,
      ),
      onPressed: () => GameUtils.quitGame(myProvider),
    );
  }

  static Container buildEndGameMessage(Data myProvider) {
    const String decorationImageAssetName = 'assets/icons/game_fail.png';

    final Widget decorationWidget = TextButton(
      child: const Image(
        image: AssetImage(decorationImageAssetName),
        fit: BoxFit.fill,
      ),
      onPressed: () {},
    );

    return Container(
      margin: const EdgeInsets.all(2),
      padding: const EdgeInsets.all(2),
      child: Table(
        defaultColumnWidth: const IntrinsicColumnWidth(),
        children: [
          TableRow(
            children: [
              Column(
                children: [decorationWidget],
              ),
              Column(
                children: [buildQuitGameButton(myProvider)],
              ),
              Column(
                children: [decorationWidget],
              ),
            ],
          ),
        ],
      ),
    );
  }
}
